@@ -1,11 +1,10 @@
 package App::CSE::Command::Check;
-$App::CSE::Command::Check::VERSION = '0.002';
+$App::CSE::Command::Check::VERSION = '0.003';
 use Moose;
 extends qw/App::CSE::Command/;
 
 use Lucy::Search::IndexSearcher;
 
-use Term::ANSIColor;
 
 use Log::Log4perl;
 my $LOGGER = Log::Log4perl->get_logger();
@@ -28,12 +27,18 @@ sub execute{
                  };
   unless( $lucy ){
     my $err = $@;
-    $LOGGER->error(colored("The index $index_dir is not a valid lucy index.", 'red bold'));
+    $LOGGER->error($self->cse->colorizer->colored("The index $index_dir is not a valid lucy index.", 'red bold'));
     $LOGGER->debug("Lucy error: $err");
     return 1;
   }
 
-  $LOGGER->info("Index $index_dir is healthy.");
+  my $dirty_str = '';
+  my $dirty_hash = $self->cse()->dirty_files();
+  if( my $ndirty = scalar( keys %$dirty_hash ) ){
+    $dirty_str  = ' '.$ndirty.' dirty files - run cse update to clean them';
+  }
+
+  $LOGGER->info("Index $index_dir is healthy.".$dirty_str);
   my $schema = $lucy->get_schema();
   my @fields = sort @{ $schema->all_fields() };
   $LOGGER->info("Fields: ".join(', ', map{ $_.' ('._scrape_lucy_class($schema->fetch_type($_)).')'  } @fields));
