@@ -1,11 +1,6 @@
 package App::CSE::File::TextXTex;
-$App::CSE::File::TextXTex::VERSION = '0.002';
+$App::CSE::File::TextXTex::VERSION = '0.003';
 use Moose;
 extends qw/App::CSE::File::TextPlain/;
 
-sub effective_object{
-  my ($self) = @_;
-  return $self;
-}
-
 __PACKAGE__->meta->make_immutable();
